;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "rfc-mode" "20260127.1807"
  "RFC document browser and viewer."
  '((emacs "25.1"))
  :url "https://github.com/galdor/rfc-mode"
  :commit "2d3dcd649e291eeb93091560b504f96162371c32"
  :revdesc "2d3dcd649e29"
  :authors '(("Nicolas Martyanoff" . "nicolas@n16f.net"))
  :maintainers '(("Nicolas Martyanoff" . "nicolas@n16f.net")))
